@@ -1,5 +1,6 @@
 import logging
-from collections import defaultdict
+import shutil
+import traceback
 from pathlib import Path
 
 import click
@@ -9,14 +10,18 @@ from tqdm import tqdm
 
 import openpecha
 from openpecha import config
+from openpecha.alignment.tmx import create_opf as alignment
 from openpecha.blupdate import PechaBaseUpdate
 from openpecha.buda.openpecha_manager import OpenpechaManager
 from openpecha.catalog import config as catalog_config
 from openpecha.catalog.filter import is_text_good_quality
 from openpecha.catalog.storage import GithubBucket
+from openpecha.core.pecha import OpenPechaFS
+from openpecha.corpus.quality import NonWordsCounter
 from openpecha.exceptions import PechaNotFound
 from openpecha.formatters import *
 from openpecha.serializers import *
+from openpecha.storages import GithubStorage, setup_auth_for_old_repo
 
 OP_PATH = config.BASE_PATH
 config = {
@@ -77,16 +82,19 @@ def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
         if needs_update:
             click.echo(INFO.format(f"Updating {pecha_id} ..."))
             repo.git.pull("origin", branch)
-        return pecha_path
+    else:
+        click.echo(INFO.format(f"Downloading {pecha_id} ..."))
+        try:
+            Repo.clone_from(pecha_url, str(pecha_path))
+        except GitCommandError:
+            raise PechaNotFound(f"Pecha with id {pecha_id} doesn't exist")
+        repo = Repo(str(pecha_path))
+        branch = _eval_branch(repo, branch)
+        repo.git.checkout(branch)
 
-    click.echo(INFO.format(f"Downloading {pecha_id} ..."))
-    try:
-        Repo.clone_from(pecha_url, str(pecha_path))
-    except GitCommandError:
-        raise PechaNotFound(f"Pecha with id {pecha_id} doesn't exist")
-    repo = Repo(str(pecha_path))
-    branch = _eval_branch(repo, branch)
-    repo.git.checkout(branch)
+    # setup auth
+    storage = GithubStorage()
+    setup_auth_for_old_repo(repo, org=storage.org_name, token=storage.token)
 
     return pecha_path
 
@@ -313,3 +321,114 @@ def update_layers(**kwargs):
     dst_opf_path = Path(kwargs["pecha_path"]) / f"{pecha_id}.opf"
     pecha = PechaBaseUpdate(src_opf_path, dst_opf_path)
     pecha.update()
+
+
+def get_alignment_ids(path):
+    path = Path(path)
+    return [line for line in path.read_text().splitlines() if line]
+
+
+alignment_import_types = ["tmx"]
+
+
+@cli.command()
+@click.argument("path")
+@click.option("--verbose", "-v", help="verbose", is_flag=True)
+@click.option("--debug", "-d", help="debug", is_flag=True)
+@click.option(
+    "--type",
+    "-t",
+    type=click.Choice(alignment_import_types),
+    help="Type of alignment import format. Default is tmx",
+)
+@click.option(
+    "--tm-path", "-tm", help="path to file containing OpenPecha alignment id's"
+)
+def import_alignment(**kwargs):
+    """
+    import existing alignment into OpenPecha
+    """
+    try:
+        from openpecha.alignment.integrations.tx import OPATransifexProject
+    except Exception:
+        raise ImportError(
+            "install with `pip install openpecha[tx]` for transifex dependencies"
+        )
+
+    if kwargs["debug"]:
+        logging.basicConfig(level=logging.DEBUG)
+    elif kwargs["verbose"]:
+        logging.basicConfig(level=logging.INFO)
+    logging.info("Creating OpenPecha alignment")
+    alignment_path = alignment.create_alignment_from_tmx(tmx_path=Path(kwargs["path"]))
+
+    added_tms_path = []
+    try:
+        logging.info(f"Alignment created at {alignment_path}")
+        project = OPATransifexProject(org_slug="esukhia", alignment_path=alignment_path)
+        project.create()
+        project.import_translation()
+        logging.info("Imported translation")
+        logging.info("Adding TMs")
+        added_tms_path = project.add_tm(
+            alignment_ids=get_alignment_ids(kwargs["tm_path"])
+        )
+    except Exception as e:
+        print(traceback.print_exc())
+        logging.info("Cleaning up")
+        # shutil.rmtree(str(alignment_path))
+    finally:
+        if alignment_path.is_dir and added_tms_path:
+            logging.info("Cleaning up")
+            if alignment_path.is_dir():
+                shutil.rmtree(str(alignment_path))
+            for path in added_tms_path:
+                shutil.rmtree(str(path))
+
+
+@cli.command()
+@click.argument("path")
+@click.option("-t", "--title", help="title of the text")
+@click.option(
+    "--tm-path", "-tm", help="path to file containing OpenPecha alignment id's"
+)
+def new_translation(**kwargs):
+    """
+    prepare translation project in transifex
+    """
+    try:
+        from openpecha.alignment.integrations.tx import OPATransifexProject
+    except Exception:
+        raise ImportError(
+            "install with `pip install openpecha[tx]` for transifex dependencies"
+        )
+
+    alignment_path = alignment.create_alignment_from_source_text(
+        text_path=Path(kwargs["path"])
+    )
+    project = OPATransifexProject(org_slug="esukhia", alignment_path=alignment_path)
+    project.create()
+    project.start_new_translation()
+    project.add_tm(alignment_ids=get_alignment_ids(kwargs["tm_path"]))
+
+
+@cli.command()
+@click.argument("pecha_path")
+@click.option("--save", "-s", help="save non-words counts", is_flag=True)
+def qc(**kwargs):
+    """
+    check quality of pecha base text
+    """
+    pecha = OpenPechaFS(path=kwargs["pecha_path"])
+
+    click.echo("Counting Non Words...")
+    non_words_count = NonWordsCounter(empty=True)
+    for base_name in pecha.components.keys():
+        text = pecha.get_base(base_name)
+        non_words_count += NonWordsCounter(text)
+
+    if kwargs["save"]:
+        pecha.meta.statistics["total_words"] = non_words_count.total_words
+        pecha.meta.statistics["total_non_words"] = non_words_count.total_non_words
+        pecha.meta.quality["non_words_ratio"] = non_words_count.non_word_ratio
+        pecha.save_meta()
