@@ -1,4 +1,6 @@
+from .docx import DocxSerializer
 from .editor import EditorSerializer
 from .epub import EpubSerializer
 from .hfml import HFMLSerializer
+from .pedurma import PedurmaSerializer
 from .rdf import Rdf
