@@ -1,5 +1,4 @@
 import re
-
 from collections import defaultdict, namedtuple
 from pathlib import Path
 
@@ -113,6 +112,21 @@ class Serialize(object):
             meta = {}
         return meta
 
+    def get_css_class_name(self, annotation):
+        """Return css class name of annotation if any exist
+
+        Args:
+            annotation (dict): annotation details
+
+        Returns:
+            str: css class name of the annotation
+        """
+        css_class_name = ""
+        metadata = annotation.get("metadata", {})
+        if metadata:
+            css_class_name = metadata.get("css_class_name", "")
+        return css_class_name
+
     def get_text_spans(self, text_id, index_layer):
         """
         get spans of text
@@ -163,7 +177,7 @@ class Serialize(object):
             vol_base = (self.opf_path / f"base/{vol_id}.txt").read_text()
             start = self.text_spans[vol_id]["start"]
             end = self.text_spans[vol_id]["end"]
-            return vol_base[start:end+1]
+            return vol_base[start : end + 1]
         else:
             vol_base = (self.opf_path / f"base/{vol_id}.txt").read_text()
             return vol_base
@@ -210,12 +224,13 @@ class Serialize(object):
         for ann_id, topic in self.index_layer["annotations"].items():
             topic_ann = defaultdict(str)
             sub_topics = topic["parts"]
-            for i, sub_topic in enumerate(sub_topics):
-                if sub_topic:
-                    vol_id = f"v{sub_topic['span']['vol']:03}"
-                    sub_topic["type"] = AnnType.sub_topic
-                    if sub_topic["work_id"] != sub_topics[i - 1]["work_id"]:
-                        self.apply_annotation(vol_id, sub_topic)
+            for sub_topic_uuid, sub_topic in sub_topics.items():
+                sub_topic_ann = defaultdict(str)
+                vol_id = f"v{sub_topic['span'][0]['vol']:03}"
+                sub_topic_ann["type"] = AnnType.sub_topic
+                sub_topic_ann["work_id"] = sub_topic["work_id"]
+                sub_topic_ann["span"] = sub_topic["span"][0]
+                self.apply_annotation(vol_id, sub_topic_ann)
             if topic["span"]:
                 vol_id = f"v{topic['span'][0]['vol']:03}"
                 topic_ann["type"] = AnnType.topic
@@ -280,31 +295,6 @@ class Serialize(object):
             "The Serialize class doesn't provide any serialization, please use a subclass such ass SerializeMd"
         )
 
-    def _assign_line_layer(self, result, vol_id):
-        def _get_page_index(line):
-            page_index = ""
-            if re.search("[𰵀-󴉱]", line):
-                i = 2
-            else:
-                i = 1
-            while line[i] != "]":
-                page_index += line[i]
-                i += 1
-            return page_index
-
-        result_with_line = ""
-        page_index = ""
-        n_line = 1
-        for line in result.split("\n"):
-            if re.search(r"\[[𰵀-󴉱]?[0-9]+[a-z]{1}\]", line):
-                page_index = _get_page_index(line)
-                n_line = 1
-            elif not re.search(r"^\[", line):
-                line = f"[{page_index}.{n_line}]" + line
-                n_line += 1
-            result_with_line += line + "\n"
-        return result_with_line
-    
     def _clip_extra_newline(self, cur_vol_result):
         """An extra line found in pages are removed.
 
@@ -314,14 +304,14 @@ class Serialize(object):
         Returns:
             str: clean serialize results
         """
-        clean_result = ''
-        pages_and_anns = re.split(r"(\[[𰵀-󴉱]?[0-9]+[a-z]{1}\])", cur_vol_result)
+        clean_result = ""
+        pages_and_anns = re.split(r"(〔[𰵀-󴉱]?\d+〕)", cur_vol_result)
         for page_and_ann in pages_and_anns:
             if page_and_ann:
-                if re.search(r"\[([𰵀-󴉱])?[0-9]+[a-z]{1}\]", page_and_ann):
+                if re.search(r"\(([𰵀-󴉱])?\d+\)", page_and_ann):
                     clean_result += page_and_ann
                 else:
-                    if page_and_ann[-1] == '\n':
+                    if page_and_ann[-1] == "\n":
                         clean_result += page_and_ann[:-1]
                     else:
                         clean_result += page_and_ann
